package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;

public class Pfx extends ASN1Encodable implements PKCSObjectIdentifiers {
   private ContentInfo contentInfo;
   private MacData macData = null;

   public Pfx(ASN1Sequence seq) {
      if (((DERInteger)seq.getObjectAt(0)).getValue().intValue() == 3) {
         this.contentInfo = ContentInfo.getInstance(seq.getObjectAt(1));
         if (seq.size() == 3) {
            this.macData = MacData.getInstance(seq.getObjectAt(2));
         }

      } else {
         throw new IllegalArgumentException("wrong version for PFX PDU");
      }
   }

   public Pfx(ContentInfo contentInfo, MacData macData) {
      this.contentInfo = contentInfo;
      this.macData = macData;
   }

   public ContentInfo getAuthSafe() {
      return this.contentInfo;
   }

   public MacData getMacData() {
      return this.macData;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(new DERInteger(3));
      var10001.add(this.contentInfo);
      MacData var2;
      if ((var2 = this.macData) != null) {
         var1.add(var2);
      }

      return new BERSequence(var1);
   }
}
